import { defHttp } from '/@/utils/http/axios'
import {
  LoginParams,
  LoginResultModel,
  GetUserInfoByUserIdParams,
  GetUserInfoByUserIdModel
} from './model/userModel'

import { ErrorMessageMode } from '/@/utils/http/axios/types'

enum Api {
  Login = '/login',
  GetUserInfoById = '/projectAccount',
  GetPermCodeByUserId = '/getPermCodeByUserId'
}

/**
 * @description: user login api
 */
export function loginApi(params: LoginParams, mode: ErrorMessageMode = 'modal') {
  return defHttp.post<LoginResultModel>(
    {
      url: Api.Login,
      params
    },
    {
      errorMessageMode: mode
    }
  )
}

/**
 * @description: getUserInfoById
 */
export function getUserInfoById() {
  return defHttp.get<GetUserInfoByUserIdModel>({
    url: Api.GetUserInfoById
  })
}

export function getPermCodeByUserId(params: GetUserInfoByUserIdParams) {
  return defHttp.get<string[]>({
    url: Api.GetPermCodeByUserId,
    params
  })
}
